# coding: utf-8

# flake8: noqa

"""
    Account Service API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from account-service_client.api.account_api import AccountApi
from account-service_client.api.default_api import DefaultApi

# import ApiClient
from account-service_client.api_response import ApiResponse
from account-service_client.api_client import ApiClient
from account-service_client.configuration import Configuration
from account-service_client.exceptions import OpenApiException
from account-service_client.exceptions import ApiTypeError
from account-service_client.exceptions import ApiValueError
from account-service_client.exceptions import ApiKeyError
from account-service_client.exceptions import ApiAttributeError
from account-service_client.exceptions import ApiException

# import models into sdk package
from account-service_client.models.profile_put_request import ProfilePutRequest
from account-service_client.models.settings import Settings
from account-service_client.models.user_profile import UserProfile



# coding: utf-8

# flake8: noqa
"""
    Account Service API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from account-service_client.models.profile_put_request import ProfilePutRequest
from account-service_client.models.settings import Settings
from account-service_client.models.user_profile import UserProfile



# coding: utf-8

"""
    Account Service API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from account-service_client.api.account_api import AccountApi


class TestAccountApi(unittest.TestCase):
    """AccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountApi()

    def tearDown(self) -> None:
        pass

    def test_profile_get(self) -> None:
        """Test case for profile_get

        Get profile
        """
        pass

    def test_profile_put(self) -> None:
        """Test case for profile_put

        Update profile
        """
        pass

    def test_settings_get(self) -> None:
        """Test case for settings_get

        Get settings
        """
        pass


if __name__ == '__main__':
    unittest.main()
